@@ -325,7 +325,7 @@ class QueueMonitor:
          if dagManJobId > 0:
             if dagManJobId in reportClusters:
                pegasus_wf_dax_job_id = pegasus_wf_dax_job_ids[clusterId]
-               if re.match("[0-9]+_[0-9]+",pegasus_wf_dax_job_id):
+               if re.match("[A-Za-z0-9]+_[0-9]+",pegasus_wf_dax_job_id):
                   if   reportClusters[dagManJobId]['jobStatusLabel'] == "":
                      reportClusters[dagManJobId]['jobStatusLabel'] = jobStatusLabels[jobStatuses[clusterId]]
                   elif jobStatusLabels[jobStatuses[clusterId]] == 'R':
@@ -346,7 +346,7 @@ class QueueMonitor:
          dagManJobId = dagManJobIds[clusterId]
          if dagManJobId > 0:
             pegasus_wf_dax_job_id = pegasus_wf_dax_job_ids[clusterId]
-            if re.match("[0-9]+_[0-9]+",pegasus_wf_dax_job_id):
+            if re.match("[A-Za-z0-9]+_[0-9]+",pegasus_wf_dax_job_id):
                instance = int(pegasus_wf_dax_job_id.split('_')[1])
                filteredRecords += "%d.%d %s %s %s\n" % (dagManJobId,instance, \
                                                                     jobStatusLabels[jobStatuses[clusterId]], \
