@@ -1,10 +1,10 @@
 # @package      hubzero-submit-monitors
 # @file         JobMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -30,8 +30,9 @@ import math
 import sqlite3
 import time
 import traceback
+import logging
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 from hubzero.submit.JobInfo     import JobInfo
 
@@ -46,18 +47,20 @@ class JobMonitor(MessageCore):
       bindLabel = "%s:%d" % (host if host else "localhost",port)
       MessageCore.__init__(self,bindHost=host,bindPort=port,bindLabel=bindLabel,
                                 reuseAddress=True,repeatDelay=repeatDelay)
+
+      self.logger            = logging.getLogger(__name__)
       self.fixedBufferSize   = fixedBufferSize
       self.activeJobDBPath   = activeJobDBPath
       self.activeJobDumpPath = activeJobDumpPath
       self.dbConnection      = None
       try:
-         self.dbConnection = sqlite3.connect(self.activeJobDBPath,isolation_level=None)
+         self.dbConnection = sqlite3.connect(self.activeJobDBPath)
          self.dbConnection.row_factory = sqlite3.Row
          nActiveJobCount = self.getActiveJobCount()
-         log("%d jobs loaded from DB file" % (nActiveJobCount))
+         self.logger.log(logging.INFO,getLogMessage("%d jobs loaded from DB file" % (nActiveJobCount)))
          self.purgeActiveJobSites()
       except:
-         log(traceback.format_exc())
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
 
 
    def dumpActiveJobs(self):
@@ -267,13 +270,13 @@ class JobMonitor(MessageCore):
                                                                                  jobInfo['nCores'],
                                                                                  jobInfo['runName'],
                                                                                  jobInfo['messageSite'],
-   				                                                 jobInfo['remoteJobId'],
-   				                                                 jobInfo['jobStatus'],
-   				                                                 jobInfo['jobStage'],
-   				                                                 jobInfo['jobQueue'],
-   				                                                 jobInfo['hubUserId'],
-   				                                                 jobInfo['destination'],
-   				                                                 jobInfo['timeRecorded']))
+   				                                                                  jobInfo['remoteJobId'],
+   				                                                                  jobInfo['jobStatus'],
+   				                                                                  jobInfo['jobStage'],
+   				                                                                  jobInfo['jobQueue'],
+   				                                                                  jobInfo['hubUserId'],
+   				                                                                  jobInfo['destination'],
+   				                                                                  jobInfo['timeRecorded']))
       self.dbConnection.commit()
 
 
@@ -410,6 +413,7 @@ class JobMonitor(MessageCore):
       for row in rows:
          currentActivityScores[row['hubUserId']] = row['activity']
 
+      updatedActivityScores = {}
       cursor.execute("SELECT * FROM userActivityScores")
       rows = cursor.fetchall()
       for row in rows:
@@ -417,19 +421,31 @@ class JobMonitor(MessageCore):
          activityScore = row['activityScore']
          timeUpdated   = row['timeUpdated']
 
+         beta = math.pow(0.5,(now-timeUpdated)/86400.)
          if hubUserId in currentActivityScores:
-            beta = math.pow(0.5,(now-timeUpdated)/86400.)
             activity  = beta*activityScore + (1.-beta)*currentActivityScores[hubUserId]
-            self.updateUserActivity(hubUserId,activity,now)
          else:
-            beta = math.pow(0.5,(now-timeUpdated)/86400.)
             activity  = beta*activityScore
-            self.updateUserActivity(hubUserId,activity,now)
+         updatedActivityScores[hubUserId] = activity
 
+      if len(updatedActivityScores) > 0:
+         cursor = self.dbConnection.cursor()
+         for hubUserId in updatedActivityScores:
+            cursor.execute("UPDATE userActivityScores SET activityScore=?,timeUpdated=? \
+                                                    WHERE(hubUserId=?)",(updatedActivityScores[hubUserId],now,hubUserId))
+         self.dbConnection.commit()
+
+      updatedActivityScores = {}
       for hubUserId in currentActivityScores:
          activityScore,timeUpdated = self.getUserActivity(hubUserId)
          if timeUpdated < 0.:
-            self.addUserActivity(hubUserId,currentActivityScores[hubUserId])
+            updatedActivityScores[hubUserId] = currentActivityScores[hubUserId]
+
+      if len(updatedActivityScores) > 0:
+         cursor = self.dbConnection.cursor()
+         for hubUserId in updatedActivityScores:
+            cursor.execute("INSERT INTO userActivityScores VALUES(?,?,?)",(hubUserId,updatedActivityScores[hubUserId],now))
+         self.dbConnection.commit()
 
 
    def processRequest(self,
@@ -457,10 +473,10 @@ class JobMonitor(MessageCore):
                      localJobId = int(localJobId)
                      instanceId = int(instanceId)
                else:
-                  log("Failed %s message request: %s" % (messageType,siteId))
+                  self.logger.log(logging.ERROR,getLogMessage("Failed %s message request: %s" % (messageType,siteId)))
                   messageType = ''
             except:
-               log("Failed QSRT message request: %s" % (message))
+               self.logger.log(logging.ERROR,getLogMessage("Failed QSRT message request: %s" % (message)))
                messageType = ''
          elif re.match('[W]:',message):
             try:
@@ -470,16 +486,16 @@ class JobMonitor(MessageCore):
                   messageSite,remoteJobId,nInstances = siteId.split()
                   nInstances = int(nInstances)
                else:
-                  log("Failed %s message request: %s" % (messageType,siteId))
+                  self.logger.log(logging.ERROR,getLogMessage("Failed %s message request: %s" % (messageType,siteId)))
                   messageType = ''
             except:
-               log("Failed W message request: %s" % (message))
+               self.logger.log(logging.ERROR,getLogMessage("Failed W message request: %s" % (message)))
                messageType = ''
          elif re.match('[AU]:',message):
             try:
                messageType,hubUserId = message.strip().split(':')
             except:
-               log("Failed AU message request: %s" % (message))
+               self.logger.log(logging.ERROR,getLogMessage("Failed AU message request: %s" % (message)))
                messageType = ''
          elif re.match('[P]:',message):
             try:
@@ -488,13 +504,13 @@ class JobMonitor(MessageCore):
                if nWords == 2:
                   hubUserId,localJobId =  siteId.split()
                else:
-                  log("Failed %s message request: %s" % (messageType,siteId))
+                  self.logger.log(logging.ERROR,getLogMessage("Failed %s message request: %s" % (messageType,siteId)))
                   messageType = ''
             except:
-               log("Failed P message request: %s" % (message))
+               self.logger.log(logging.ERROR,getLogMessage("Failed P message request: %s" % (message)))
                messageType = ''
          else:
-            log("Failed message request: " + message)
+            self.logger.log(logging.ERROR,getLogMessage("Failed message request: " + message))
             messageType = ''
 
          if   messageType == 'Q':                        # job Query
@@ -742,7 +758,7 @@ class JobMonitor(MessageCore):
             channel.close()
             channelClosed = True
          except:
-            log("close channel failed")
+            self.logger.log(logging.ERROR,getLogMessage("close channel failed"))
 
       return(channelClosed,newJobSite,newJobId)
 
