@@ -1,10 +1,10 @@
 # @package      hubzero-submit-monitors
 # @file         TunnelMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -31,8 +31,9 @@ import subprocess
 import shlex
 import select
 import signal
+import logging
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class TunnelMonitor(MessageCore):
@@ -44,6 +45,8 @@ class TunnelMonitor(MessageCore):
                 updateknownHostsCommand="update-known-hosts"):
       bindLabel = "%s:%d" % (host if host else "localhost",port)
       MessageCore.__init__(self,bindHost=host,bindPort=port,bindLabel=bindLabel,repeatDelay=repeatDelay)
+
+      self.logger                  = logging.getLogger(__name__)
       self.fixedBufferSize         = fixedBufferSize
       self.updateknownHostsCommand = updateknownHostsCommand
       self.bufferSize              = 4096
@@ -97,12 +100,12 @@ class TunnelMonitor(MessageCore):
       pid,err = os.waitpid(childPid,0)
       if err != 0:
          if os.WIFSIGNALED(err):
-            log("%s failed w/ signal %d" % (command,os.WTERMSIG(err)))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ signal %d" % (command,os.WTERMSIG(err))))
          else:
             if os.WIFEXITED(err):
                err = os.WEXITSTATUS(err)
-            log("%s failed w/ exit code %d" % (command,err))
-         log("%s" % ("".join(errData)))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ exit code %d" % (command,err)))
+         self.logger.log(logging.ERROR,getLogMessage("%s" % ("".join(errData))))
 
       return(err,"".join(outData),"".join(errData))
 
@@ -161,12 +164,12 @@ class TunnelMonitor(MessageCore):
          pid,err = os.waitpid(childPid,0)
       if err != 0:
          if os.WIFSIGNALED(err):
-            log("%s failed w/ signal %d" % (command,os.WTERMSIG(err)))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ signal %d" % (command,os.WTERMSIG(err))))
          else:
             if os.WIFEXITED(err):
                err = os.WEXITSTATUS(err)
-            log("%s failed w/ exit code %d" % (command,err))
-         log("%s" % ("".join(errData)))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ exit code %d" % (command,err)))
+         self.logger.log(logging.ERROR,getLogMessage("%s" % ("".join(errData))))
 
       return(err,"".join(outData),"".join(errData))
 
@@ -185,9 +188,9 @@ class TunnelMonitor(MessageCore):
                messageType,tunnelName = message.split(':')
                tunnelName = tunnelName.strip()
             except:
-               log("Failed AIDTR message request: " + message)
+               self.logger.log(logging.ERROR,getLogMessage("Failed AIDTR message request: " + message))
          else:
-            log("Failed message request: " + message)
+            self.logger.log(logging.ERROR,getLogMessage("Failed message request: " + message))
             messageType = ""
 
          if   messageType == 'A':                        # get tunnel Address and port
@@ -209,23 +212,23 @@ class TunnelMonitor(MessageCore):
                      exitStatus = self.__executeCommand(updateCommand)[0]
                      if exitStatus == 0:
                         sshTunnelCommand = tunnelsInfo.getSSHTunnelCommand(tunnelName,sshIdentity)
-                        log(sshTunnelCommand)
+                        self.logger.log(logging.INFO,getLogMessage(sshTunnelCommand))
                         exitStatus,stdOutput,stdError = self.__executeTunnelCommand(sshTunnelCommand)
                         if exitStatus == 0:
                            sshTunnelPidCommand = tunnelsInfo.getSSHTunnelPidCommand(tunnelName)
-                           log(sshTunnelPidCommand)
+                           self.logger.log(logging.INFO,getLogMessage(sshTunnelPidCommand))
                            exitStatus,tunnelPid,stdPidError = self.__executeCommand(sshTunnelPidCommand)
                            tunnelPid = tunnelPid.strip()
                            if exitStatus == 0:
                               useCount = "1"
                               activeTunnels[tunnelName] = (tunnelPid,useCount)
-                              log("%s tunnel started, pid = %s" % (tunnelName,tunnelPid))
+                              self.logger.log(logging.INFO,getLogMessage("%s tunnel started, pid = %s" % (tunnelName,tunnelPid)))
                            else:
-                              log(tunnelPid)
-                              log(stdPidError)
+                              self.logger.log(logging.ERROR,getLogMessage(tunnelPid))
+                              self.logger.log(logging.ERROR,getLogMessage(stdPidError))
                         else:
-                           log(stdOutput)
-                           log(stdError)
+                           self.logger.log(logging.ERROR,getLogMessage(stdOutput))
+                           self.logger.log(logging.ERROR,getLogMessage(stdError))
             self.sendMessage(channel,useCount,self.fixedBufferSize)
          elif messageType == 'D':                        # Decrement tunnel usage
             if tunnelName in activeTunnels:
@@ -234,7 +237,7 @@ class TunnelMonitor(MessageCore):
                if int(useCount) == 0:
                   os.kill(int(tunnelPid),signal.SIGTERM)
                   del activeTunnels[tunnelName]
-                  log("%s tunnel stopped, pid = %s" % (tunnelName,tunnelPid))
+                  self.logger.log(logging.INFO,getLogMessage("%s tunnel stopped, pid = %s" % (tunnelName,tunnelPid)))
                else:
                   activeTunnels[tunnelName] = (tunnelPid,useCount)
             else:
@@ -245,7 +248,7 @@ class TunnelMonitor(MessageCore):
                tunnelPid,useCount = activeTunnels[tunnelName]
                os.kill(int(tunnelPid),signal.SIGTERM)
                del activeTunnels[tunnelName]
-               log("%s tunnel stopped, pid = %s" % (tunnelName,tunnelPid))
+               self.logger.log(logging.INFO,getLogMessage("%s tunnel stopped, pid = %s" % (tunnelName,tunnelPid)))
             else:
                useCount = "0"
             self.sendMessage(channel,useCount,self.fixedBufferSize)
@@ -274,7 +277,7 @@ class TunnelMonitor(MessageCore):
             channel.close()
             channelClosed = True
          except:
-            log("close channel failed")
+            self.logger.log(logging.ERROR,getLogMessage("close channel failed"))
 
       return(channelClosed)
 
